class FilterGroupController:
    def __init__(self, filterGroups):
        self.filterGroups = filterGroups

    def sendCoT(self, CoT):
        pass

    def addUser(self, clientInformation):
        pass

    def removeUser(self, clientInformation):
        pass