#######################################################
# 
# MainSocketController.py
# Python implementation of the Class MainSocketController
# Generated by Enterprise Architect
# Created on:      21-May-2020 12:23:05 PM
# Original author: Natha Paquette
# 
#######################################################
from FreeTAKServer.model.sockets.MainSocket import MainSocket


class MainSocketController:
    def __init__(self):  
        self.MainSocket = MainSocket()

    def changeIP(self, IP):
        self.MainSocket.ip = IP

    def changePort(self, port):
        self.MainSocket.port = port

    def createSocket(self):
        pass