#######################################################
# 
# SimpleAPIMessageAbstract.py
# Python implementation of the Class SimpleAPIMessageAbstract
# Generated by Enterprise Architect
# Created on:      17-Oct-2020 2:41:46 PM
# Original author: natha
# 
#######################################################


class SimpleAPIMessageAbstract:
# default constructor  def __init__(self):  

    # the type of the CoT which is a key in the enumeration and begins with a-.
    COTTYPE = ""  
    # a string which is a key in the how enumeration.
    how = ""  
    # this will be embedded within the COTTYPE.
    ID = ""  
    # the latitude value of the CoT 
    lat = ""  
    # the longitude value of the CoT
    lon = ""  