#######################################################
# 
# ActiveThreads.py
# Python implementation of the Class ActiveThreads
# Generated by Enterprise Architect
# Created on:      21-May-2020 10:18:14 AM
# Original author: Natha Paquette
# 
#######################################################


class ActiveThreads:
# default constructor  def __init__(self):  

    ThreadArray = []
