#######################################################
# 
# ReceiveConnectionsProcess.py
# Python implementation of the Class ReceiveConnectionsProcess
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:47:41 AM
# Original author: Natha Paquette
# 
#######################################################

class ReceiveConnectionsProcess:
    def __init__(self):  
        self.receiveConnections = ""
