#######################################################
# 
# StopHandler.py
# Python implementation of the Class StopHandler
# Generated by Enterprise Architect
# Created on:      29-Dec-2020 8:10:47 AM
# Original author: natha
# 
#######################################################
from Catalog.Data.Federation.Handler import Handler

class StopHandler(Handler):
# default constructor  def __init__(self):  

    def Handle(object, command):
        pass

    def setNextHandler(handler):
        pass