#######################################################
# 
# Federate.py
# Python implementation of the Class Federate
# Generated by Enterprise Architect
# Created on:      29-Dec-2020 8:10:34 AM
# Original author: natha
# 
#######################################################
import socket

class Federate:
# default constructor  def __init__(self):  
    def __init__(self):
        self.name = str
        self.uid = str
        self.addr = tuple
        self.conn = socket.socket