#######################################################
# 
# DataQueueController.py
# Python implementation of the Class DataQueueController
# Generated by Enterprise Architect
# Created on:      20-May-2020 1:09:37 PM
# Original author: Natha Paquette
# 
#######################################################


class DataQueueController:
# default constructor  def __init__(self):  

    def addData(CoTObject):
        pass

    def addDataToAllQueues(CoTObject):
        pass

    def addDataToSpecificQueue(CoTObject):
        pass

    def checkPrivacy(CoTObject):
        pass