# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: detail.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import FreeTAKServer.model.protobufModel.contact_pb2 as contact__pb2
import FreeTAKServer.model.protobufModel.group_pb2 as group__pb2
import FreeTAKServer.model.protobufModel.precisionlocation_pb2 as precisionlocation__pb2
import FreeTAKServer.model.protobufModel.status_pb2 as status__pb2
import FreeTAKServer.model.protobufModel.takv_pb2 as takv__pb2
import FreeTAKServer.model.protobufModel.track_pb2 as track__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='detail.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x64\x65tail.proto\x1a\rcontact.proto\x1a\x0bgroup.proto\x1a\x17precisionlocation.proto\x1a\x0cstatus.proto\x1a\ntakv.proto\x1a\x0btrack.proto\"\xc1\x01\n\x06\x44\x65tail\x12\x11\n\txmlDetail\x18\x01 \x01(\t\x12\x19\n\x07\x63ontact\x18\x02 \x01(\x0b\x32\x08.Contact\x12\x15\n\x05group\x18\x03 \x01(\x0b\x32\x06.Group\x12-\n\x11precisionLocation\x18\x04 \x01(\x0b\x32\x12.PrecisionLocation\x12\x17\n\x06status\x18\x05 \x01(\x0b\x32\x07.Status\x12\x13\n\x04takv\x18\x06 \x01(\x0b\x32\x05.Takv\x12\x15\n\x05track\x18\x07 \x01(\x0b\x32\x06.Trackb\x06proto3'
  ,
  dependencies=[contact__pb2.DESCRIPTOR,group__pb2.DESCRIPTOR,precisionlocation__pb2.DESCRIPTOR,status__pb2.DESCRIPTOR,takv__pb2.DESCRIPTOR,track__pb2.DESCRIPTOR,])




_DETAIL = _descriptor.Descriptor(
  name='Detail',
  full_name='Detail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xmlDetail', full_name='Detail.xmlDetail', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='Detail.contact', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='Detail.group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precisionLocation', full_name='Detail.precisionLocation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Detail.status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='takv', full_name='Detail.takv', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track', full_name='Detail.track', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=302,
)

_DETAIL.fields_by_name['contact'].message_type = contact__pb2._CONTACT
_DETAIL.fields_by_name['group'].message_type = group__pb2._GROUP
_DETAIL.fields_by_name['precisionLocation'].message_type = precisionlocation__pb2._PRECISIONLOCATION
_DETAIL.fields_by_name['status'].message_type = status__pb2._STATUS
_DETAIL.fields_by_name['takv'].message_type = takv__pb2._TAKV
_DETAIL.fields_by_name['track'].message_type = track__pb2._TRACK
DESCRIPTOR.message_types_by_name['Detail'] = _DETAIL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Detail = _reflection.GeneratedProtocolMessageType('Detail', (_message.Message,), {
  'DESCRIPTOR' : _DETAIL,
  '__module__' : 'detail_pb2'
  # @@protoc_insertion_point(class_scope:Detail)
  })
_sym_db.RegisterMessage(Detail)


# @@protoc_insertion_point(module_scope)
