#######################################################
# 
# SimpleCoT.py
# Python implementation of the Class SimpleCoT
# Generated by Enterprise Architect
# Created on:      17-Oct-2020 2:41:49 PM
# Original author: natha
# 
#######################################################
from FreeTAKServer.model.RestMessages.SimpleAPIMessageAbstract import SimpleAPIMessageAbstract

class SimpleCoT(SimpleAPIMessageAbstract):

# default constructor  def __init__(self):  

    pass