#######################################################
# 
# RawConnectionInformation.py
# Python implementation of the Class RawConnectionInformation
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:47:28 AM
# Original author: Natha Paquette
# 
#######################################################


class RawConnectionInformation:
    def __init__(self):
        self.type = 'RawConnectionInformation'
        self.xmlString = ""
        self.ip = ""
        self.socket = ""
