#######################################################
# 
# DataQueue.py
# Python implementation of the Class DataQueue
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:47:23 AM
# Original author: Natha Paquette
# 
#######################################################


class DataQueue:
# default constructor  def __init__(self):  

    __dataArray = "" 