#######################################################
# 
# Contact.py
# Python implementation of the Class Contact
# Generated by Enterprise Architect
# Created on:      26-Sep-2020 9:41:39 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, ForeignKey
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy import String
from sqlalchemy.orm import relationship

class Contact(Base):
# default constructor  def __init__(self):  

    __tablename__ = "Contact"
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    Detail = relationship("Detail", back_populates="contact")
    # The unit's voice call sign
    callsign = Column(String)
    # DSN number for this element (if applicable)
    dsn = Column(String)
    # e-mail address for this element (if applicable)
    email = Column(String)
    # TBD
    endpoint = Column(String)
    # The frequency (in MHz) on which the unit may be contacted via voice.
    freq = Column(String)
    # DNS-resolvable host name
    hostname = Column(String)
    iconsetpath = Column(String)
    # Amplifies the radio frequency information provided.  Contains the modulation
    # type for the communication.  (Coding tbd, should cover complex modulations such
    # as SINCGARS hopping, csma, etc...) am|fm
    modulation = Column(String)
    # Phone number for this element (if applicable)
    phone = Column(String)
    # Version tag for this sub schema.  Necessary to ensure upward compatibility with
    # future revisions.
    version = Column(String)

