#######################################################
# 
# ReceiveConnectionsProcessController.py
# Python implementation of the Class ReceiveConnectionsProcessController
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:35:07 AM
# Original author: Natha Paquette
# 
#######################################################
from FreeTAKServer.model.ReceiveConnectionsProcess import ReceiveConnectionsProcess

class ReceiveConnectionsProcessController:
    def __init__(self):  
        self.ReceiveConnectionsProcess = ReceiveConnectionsProcess()

    def InstantiateModel(self, ReceiveConnectionProcess):
        self.ReceiveConnectionsProcess.receiveConnections = ReceiveConnectionProcess
        return self.ReceiveConnectionsProcess.receiveConnections
