#######################################################
# 
# UserConfiguration.py
# Python implementation of the Class UserConfiguration
# Generated by Enterprise Architect
# Created on:      21-Sep-2020 10:28:11 PM
# Original author: natha
# 
#######################################################
from PSM.Column import Column
from PSM.Root import Root

class UserConfiguration(Root):
# default constructor  def __init__(self):  

    Group = ""    
    Password = ""    
    UserName = ""    