#######################################################
# 
# Status.py
# Python implementation of the Class Status
# Generated by Enterprise Architect
# Created on:      26-Sep-2020 9:41:29 PM
# Original author: natha
# 
from sqlalchemy import Column
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy import String
from sqlalchemy import ForeignKey


class Status(Base):
# default constructor  def __init__(self):  
    __tablename__ = "Status"
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    # % of the battery on the phone
    battery = Column(String)
    # probably boolean to determine if ready or not
    readiness = Column(String)