class CreatorUidVariables:
    @classmethod
    def ExcheckUpdate(cls):
        cls.INTAG = None
        return cls

    @classmethod
    def Checklist(cls):
        cls.INTAG = None
        return cls

