#######################################################
# 
# Presence.py
# Python implementation of the Class Presence
# Generated by Enterprise Architect
# Created on:      04-Nov-2020 4:27:12 PM
# Original author: natha
# 
#######################################################
from FreeTAKServer.model.RestMessages.RestEnumerations import RestEnumerations


class Presence:
# default constructor  def __init__(self):  
    how = ""
    # the angular distance of the geoobject from the meridian of the greenwich, UK
    # expressed in positive or negative float. (e.g -76.107.7998)
    latitude = ""
    longitude = ""
    name = ""
    # the given role within the team . Please see API documentation for a list of
    # valid entries.
    role = ""
    # the color of the team
    team = ""
    timeout = ""