#######################################################
# 
# Archive.py
# Python implementation of the Class Archive
# Generated by Enterprise Architect
# Created on:      26-Sep-2020 9:41:27 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, ForeignKey
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy.orm import relationship


class Archive(Base):

    __tablename__ = 'Archive'
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    Detail = relationship("Detail", back_populates="archive")