#######################################################
# 
# ClientSendHandler.py
# Python implementation of the Class ClientSendHandler
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:46:48 AM
# Original author: Natha Paquette
# 
#######################################################


class ClientSendHandler:
# default constructor  def __init__(self):  

    def attemptToSendData():
        pass

    def monitorDataQueue():
        pass

    def serializeModelObject():
        pass