#######################################################
# 
# takv.py
# Python implementation of the Class takv
# Generated by Enterprise Architect
# Created on:      28-Sep-2020 10:48:20 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, ForeignKey
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy import String
from sqlalchemy.orm import relationship


class Takv(Base):
# default constructor  def __init__(self):
    __tablename__ = "Takv"
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    Detail = relationship("Detail", back_populates="takv")
    # type of physical device
    device = Column(String)
    # the operating system running TAK
    os = Column(String)
    # the variant of TAK
    platform = Column(String)
    # the version of TAK running on the device
    version = Column(String)