#######################################################
# 
# Chat.py
# Python implementation of the Class Chat
# Generated by Enterprise Architect
# Created on:      04-Nov-2020 4:26:46 PM
# Original author: natha
# 
#######################################################


class Chat:
# default constructor  def __init__(self):  
    # the text of the GeoChat message
    message = ""
    # the name of the chat's sender, changing this will also change the chat room for
    # the client.
    sender = ""