#######################################################
# 
# VideoStream.py
# Python implementation of the Class VideoStream
# Generated by Enterprise Architect
# Created on:      21-Sep-2020 10:23:44 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, func
from FreeTAKServer.model.SQLAlchemy.Root import Base, Root
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import DateTime


class VideoStream(Base, Root):
# default constructor  def __init__(self):  

    __tablename__ = "VideoStreams"
    PrimaryKey = Column(Integer, primary_key = True, autoincrement=True)
    Address = Column(String)
    Alias = Column(String)
    Buffer = Column(Integer, default=-1)
    FullXmlString = Column(String)
    IgnoreEmbeddedKlv = Column(String, default=False)
    Path = Column(String, default=None)
    Port = Column(Integer, default=-1)
    PreferredMacAddress = Column(String, default=None)
    Protocol = Column(String)
    RoverPort = Column(Integer, default=-1)
    RtspReliable = Column(Integer, default=0)
    Timeout = Column(Integer)
    Timestamp = Column(DateTime, default=func.now())