from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
#######################################################
# 
# EntityTypes.py
# Python implementation of the Class EntityTypes
# Generated by Enterprise Architect
# Created on:      11-Feb-2020 11:08:09 AM
# Original author: Corvo
# 
#######################################################


class EntityTypes(FTSProtocolObject):
# default constructor       def __init__(self):  

   military = "" 
   

      
   civilian = "" 
   # civilian getter 
   def getcivilian(self): 
      return self.civilian 
 
     # civilian setter 
   def setcivilian(self, civilian=0):  
      self.civilian=civilian 

        # military getter 
   def getmilitary(self): 
      return self.military 

    # military setter 
   def setmilitary(self, military=0):  
      self.military=military 
 
     