#######################################################
# 
# Marti.py
# Python implementation of the Class Marti
# Generated by Enterprise Architect
# Created on:      26-Sep-2020 9:41:44 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, ForeignKey
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy.orm import relationship


class Marti(Base):
# default constructor  def __init__(self):
    __tablename__ = "Marti"
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    dest = relationship("Dest", backref="owner")
