#######################################################
# 
# Federate.py
# Python implementation of the Class Federate
# Generated by Enterprise Architect
# Created on:      12-Sep-2020 10:32:00 PM
# Original author: natha
# 
#######################################################

class Federate:
    """this object contains all pertenent information in relation to one federate
    connected to server service or to which FTS is connected as a client.
    """
# default constructor  def __init__(self):  

    IP = ""  
    Port = "None"   
    Socket = ""
    federationController = None