#######################################################
# 
# ClientInformation.py
# Python implementation of the Class ClientInformation
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:47:19 AM
# Original author: Natha Paquette
# 
#######################################################
import copy

class ClientInformation:
    def __init__(self):  
        self.modelObject = ''
        self.alive = "" 
        self.dataQueue = "" 
        self.ID = "" 
        self.idData = "" 
        self.IP = "" 
        self.receptionHandler = "" 
        self.sendData = "" 
        self.socket = "" 
        self.type = "clientInformation"

    def __deepcopy__(self, memodict={}):
        returned = ClientInformation()
        returned.modelObject = copy.deepcopy(self.modelObject)
        returned.alive = copy.deepcopy(self.alive)
        returned.dataQueue = copy.deepcopy(self.dataQueue)
        returned.ID = copy.deepcopy(self.ID)
        returned.idData = copy.deepcopy(self.idData)
        returned.IP = copy.deepcopy(self.IP)
        returned.receptionHandler = copy.deepcopy(self.receptionHandler)
        returned.sendData = copy.deepcopy(self.sendData)
        returned.type = copy.deepcopy(self.type)
        return returned