#######################################################
# 
# _group.py
# Python implementation of the Class _group
# Generated by Enterprise Architect
# Created on:      28-Sep-2020 10:48:10 PM
# Original author: natha
# 
#######################################################
from sqlalchemy import Column, ForeignKey, String
from FreeTAKServer.model.SQLAlchemy.Root import Base
from sqlalchemy.orm import relationship


class _Group(Base):
# default constructor  def __init__(self):  
    __tablename__ = "_Group"
    PrimaryKey = Column(ForeignKey("Detail.PrimaryKey"), primary_key=True)
    Detail = relationship("Detail", back_populates="_group")
    name = Column(String)
    role = Column(String)