#######################################################
# 
# RawCoT.py
# Python implementation of the Class RawCoT
# Generated by Enterprise Architect
# Created on:      21-May-2020 9:47:30 AM
# Original author: Natha Paquette
# 
#######################################################


class RawCoT:
    def __init__(self):  
        self.type = "RawCoT"
        self.CoTType = "" 
        self.clientInformation = ""
        self.xmlString = b""
        self.disconnect = 0
        self.status = ''
        self.protocol = 'xml'
