from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
class Archive(FTSProtocolObject):
    def __init__(self):
        pass

    @staticmethod
    def drop_point():
        pass