#######################################################
# 
# Teams.py
# Python implementation of the Enumeration Teams
# Generated by Enterprise Architect
# Created on:      04-Nov-2020 4:43:17 PM
# Original author: natha
# 
#######################################################


class Teams:
# default constructor  def __init__(self):  
    # default constructor  def __init__(self):  


    Yellow = "" 
    Red = "" 
    Green = "" 
    Blue = "" 
