from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
#######################################################
#
# __serverdestination.py
# Python implementation of the Class __serverdestination
# Generated by Enterprise Architect
# Created on(FTSProtocolObject):      11-Feb-2020 11(FTSProtocolObject):08(FTSProtocolObject):10 AM
# Original author: Corvo
#
#######################################################
from FreeTAKServer.model.FTSModelVariables.ServerdestinationVariables import ServerdestionationVariables as vars

class _Serverdestination(FTSProtocolObject):
    def __init__(self):
        # string composed by IP:port: protocol:machineID. e.g. 192.168.0.103:4242:tcp:
        # ANDROID-R52JB0CDC4E
        self.destinations = None
        # destinations getter

    @staticmethod
    def geochat(DESTINATIONS = vars.geochat().DESTINATIONS):
        serverdestinations = _Serverdestination()
        serverdestinations.setdestinations(DESTINATIONS)
        return serverdestinations

    def getdestinations(self):
        return self.destinations

    # destinations setter
    def setdestinations(self, destinations=None):
        self.destinations = destinations