class UidVariables:
    def __init__(self):
        self.DROID = None
        self.INTAG = None

    @classmethod
    def connection(cls):
        cls.DROID = None
        return cls

    @classmethod
    def UserUpdate(cls):
        cls.Droid = None
        return cls

    @classmethod
    def ExcheckUpdate(cls):
        cls.INTAG = None
        return cls
    @classmethod
    def Checklist(cls):
        cls.INTAG = None
        return cls