from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
class ChecklistTasks(FTSProtocolObject):
    @staticmethod
    def Checklist():
        checklistTasks = ChecklistTasks()
        return checklistTasks

