class FederationClientServiceVariables:
    def __init__(self):
        self.FederationClientServiceStatus = ''
        self.FederationClientServicePort = 9000
        self.FederationClientServiceIP = None