#######################################################
# 
# MessageTypeController.py
# Python implementation of the Class MessageTypeController
# Generated by Enterprise Architect
# Created on:      20-May-2020 1:09:05 PM
# Original author: Natha Paquette
# 
#######################################################


class MessageTypeController:
    def __init__(self):  
        pass

    def callMessageController(self, data, messageType):
        pass

    def determineMessageType(self, data):
        pass