# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: takmessage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import FreeTAKServer.model.protobufModel.cotevent_pb2 as cotevent__pb2
import FreeTAKServer.model.protobufModel.takcontrol_pb2 as takcontrol__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='takmessage.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10takmessage.proto\x1a\x0e\x63otevent.proto\x1a\x10takcontrol.proto\"J\n\nTakMessage\x12\x1f\n\ntakControl\x18\x01 \x01(\x0b\x32\x0b.TakControl\x12\x1b\n\x08\x63otEvent\x18\x02 \x01(\x0b\x32\t.CotEventb\x06proto3'
  ,
  dependencies=[cotevent__pb2.DESCRIPTOR,takcontrol__pb2.DESCRIPTOR,])




_TAKMESSAGE = _descriptor.Descriptor(
  name='TakMessage',
  full_name='TakMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='takControl', full_name='TakMessage.takControl', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cotEvent', full_name='TakMessage.cotEvent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=128,
)

_TAKMESSAGE.fields_by_name['takControl'].message_type = takcontrol__pb2._TAKCONTROL
_TAKMESSAGE.fields_by_name['cotEvent'].message_type = cotevent__pb2._COTEVENT
DESCRIPTOR.message_types_by_name['TakMessage'] = _TAKMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TakMessage = _reflection.GeneratedProtocolMessageType('TakMessage', (_message.Message,), {
  'DESCRIPTOR' : _TAKMESSAGE,
  '__module__' : 'takmessage_pb2'
  # @@protoc_insertion_point(class_scope:TakMessage)
  })
_sym_db.RegisterMessage(TakMessage)


# @@protoc_insertion_point(module_scope)
